@@ -1,6 +1,6 @@
 import http.client
 import json
-from typing import Sequence
+from typing import Sequence, Union
 from . import decorators
 
 
@@ -25,7 +25,7 @@ class Request:
     def get(self, path: str):
         return self.request(path, 'GET', headers={'authorization': self.headers.pop('authorization')})
 
-    def post(self, path: str, payload: dict | Sequence | set = None):
+    def post(self, path: str, payload: Union[dict, Sequence, set] = None):
         if payload:
             return self.request(path, 'POST', headers=self.headers, payload=json.dumps(payload))
         return self.request(path, 'POST', headers=self.headers)
